/****************************************
 * Reception et afficahge des donnees de capteurs
 * Module 4 entrees analogiques / 8 numériques vers Midi
 * Interface-Z
 * Sensors data reception and display from
 * 4 analogical ways / 8 digital ways to Midi
 *****************************************/

import rwmidi.*;
// RWMidi se trouve chez http://ruinwesen.com/blog?id=95

MidiInput input;

void setup() {
  size(300, 200);
  smooth();
  noStroke();
  background(0);

  // Affichage des peripheriques Midi disponibles  
  // Displaying Midi devices existing on the computer  
  println("........Peripheriques Midi In........");
  println(RWMidi.getInputDevices());

  // Choisir le numero du peripherique dans la liste
  // Ce numero, ici [1] correspond au port Midi utilise par la carte.
  // Choose the appropriate Midi device from the list
  input = RWMidi.getInputDevices()[1].createInput(this);

  PFont fontA = loadFont("CourierNew-12.vlw");
  textFont(fontA, 12);

}

// Reception des capteurs tout ou rien
// Receiving "all or nothing" sensors
int[] inter_4 = new int[8];
int pitch;

void noteOnReceived(Note note) {
  pitch = note.getPitch();
  if ((pitch>=8)&&(pitch<16)) {  
    pitch = pitch-8;
    inter_4[pitch] = note.getVelocity(); 
    println("Note On " + pitch + " " + inter_4[pitch]);
  }
}

// Reception des capteurs analogiques
// Receiving analogical sensors
int[] valeur = new int[8];
int numero;

void controllerChangeReceived(Controller ctlchg) {
  numero = ctlchg.getCC();
  if ((numero<52)&&(numero>47)) {
    numero = numero-48;  
    valeur[numero] = ctlchg.getValue();
    println("Capteur n°" + (numero+1) + " " + valeur[numero]);
  }
}


void draw() {
  fill(255);
  text("4 Analogiques / 8 Numeriques Midi", 20, 30);

  // Affichage des entrees numeriques
  // Displaying digital ways

  // Carres bleus
  fill(0, 70, 200);
  for(int i=0; i<8; i++) {
    rect(260, 12+(i*20), 16, 16);
    // Numeros des interrupteurs
    text(i, 280, 24+(i*20));
  }
  for(int i=0; i<8; i++) {
    // Opacite 0 quand interrupteur inactif
    fill(0,190,200,inter_4[i]*4);
    rect(262, 14+(i*20), 12, 12);
  } 

  // Affichage des entrees analogiques
  // Displaying analogical ways

  // Blocs bleus
  fill(0, 0, 255);
  for(int i=0; i<4; i++) {
    rect(60+(i*30), 40, 20, 128);
    // Numeros des capteurs
    text(i+1, 65+(i*30), 185);
  }
  // Curseur dependant du capteur
  fill(0,190,255);
  for(int i=0; i<4; i++) {
    rect(60+(i*30), 167-valeur[i], 20, valeur[i]);
  }  
}




